@@ -235,6 +235,9 @@ class Import(object):
         # Define the sample
         self.sample_name, self.sample_cuts, query = self._define_sample(filename)
 
+        #Write the sample cuts and cosmo to file for next time
+        self._write_sample_cuts_cosmo(filename,self.sample_name,self.sample_cuts)
+        
         #Import the project file
         self._project_file_import(filename, query)
 
@@ -242,22 +245,22 @@ class Import(object):
 
         #Calculate the comoving distance to each particle.
         self.survey_data['c_dist'] = cd.comoving_distance(self.survey_data["redshift"], **self.cosmology)
-        lum_dist = self._LumDistance(self.survey_data['c_dist'])
+        lum_dist = lf.lum_dist(self.survey_data['redshift'],self.survey_data['c_dist'])
 
         #Here we have three options. Either mag_r AND mag_g are in the data, or only mag_r, or only mag_g or none.
         #We can only do K-Correction if both apparent magnitudes are present.
         if 'mag_r' in self.survey_data.columns and 'mag_g' in self.survey_data.columns:
             #Find the g-r colour and K-Correction to find Abs_Mag and luminosity.
             gr = self.survey_data["mag_g"] - self.survey_data["mag_r"]
-            self.survey_data['kcorr'] = self._KCorrect(gr)
+            self.survey_data['kcorr'] = lf.k_correct(self.survey_data['redshift'],gr)
 
-            self.survey_data["absmag"] = self._AbsoluteMag(lum_dist, self.survey_data['kcorr'])
-            self.survey_data['lum'] = self._LuminosityFromAbsMag(self.survey_data['absmag'])
+            self.survey_data["absmag"] = lf.absolute_mag(self.survey_data['mag_r'],lum_dist, self.survey_data['kcorr'])
+            self.survey_data['lum'] = lf.absmag_to_lum(self.survey_data['absmag'])
             
         elif 'mag_g' in self.survey_data.dtype.names:
             #calculate absmag and luminosities without K-Correction
-            self.survey_data["absmag"] = self._AbsoluteMag(lum_dist)
-            self.survey_data['lum'] = self._LuminosityFromAbsMag(self.survey_data['absmag'])
+            self.survey_data["absmag"] = lf.absolute_mag(self.survey_data['mag_r'],lum_dist)
+            self.survey_data['lum'] = lf.absmag_to_lum(self.survey_data['absmag'])
 
         else:
             sys.exit("You have no apparent magnitude in g-band specified. Try again.")
@@ -468,6 +471,21 @@ class Import(object):
 
         store.close()
 
+    def _write_sample_cuts_cosmo(self,filename,sample_name,sample_cuts):
+        
+        store = pandas.HDFStore(filename)
+        
+        #Write the sample_cuts ('all') to project file
+        store[sample_name+'_cuts'] = sample_cuts
+
+        #Write the cosmology to project file
+        cosmo = pandas.DataFrame(index=[0])
+        for key, val in self.cosmology.iteritems():
+            cosmo[key] = [val]
+        store[sample_name+'_cosmo'] = cosmo
+
+        self._create_sample_dir('all')
+        
     def _project_file_import(self, filename, query):
         """
         A simple function to import the project data
@@ -515,6 +533,7 @@ class Import(object):
             else:
                 sample_cuts = self._convert_sample_cuts()
 
+            sample_name = str(raw_input("Please choose a name for the sample: "))
         #Define query string from sample cuts
         query = self._make_query(sample_cuts)
 
